# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['swarms',
 'swarms.agents',
 'swarms.agents.boss',
 'swarms.agents.misc',
 'swarms.agents.workers',
 'swarms.agents.workers.models',
 'swarms.agents.workers.models.GroundingDINO',
 'swarms.agents.workers.models.GroundingDINO.demo',
 'swarms.agents.workers.models.GroundingDINO.groundingdino',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.config',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.datasets',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.models',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.models.GroundingDINO',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.models.GroundingDINO.backbone',
 'swarms.agents.workers.models.GroundingDINO.groundingdino.util',
 'swarms.agents.workers.models.segment_anything',
 'swarms.agents.workers.models.segment_anything.scripts',
 'swarms.agents.workers.models.segment_anything.segment_anything',
 'swarms.agents.workers.models.segment_anything.segment_anything.modeling',
 'swarms.agents.workers.models.segment_anything.segment_anything.utils',
 'swarms.prompts',
 'swarms.tools',
 'swarms.utils']

package_data = \
{'': ['*'],
 'swarms.agents.workers.models.GroundingDINO': ['.asset/*'],
 'swarms.agents.workers.models.GroundingDINO.groundingdino.models.GroundingDINO': ['csrc/*',
                                                                                   'csrc/MsDeformAttn/*'],
 'swarms.agents.workers.models.segment_anything': ['assets/*',
                                                   'demo/*',
                                                   'demo/configs/webpack/*',
                                                   'demo/src/*',
                                                   'demo/src/assets/*',
                                                   'demo/src/assets/data/*',
                                                   'demo/src/assets/scss/*',
                                                   'demo/src/components/*',
                                                   'demo/src/components/helpers/*',
                                                   'demo/src/components/hooks/*',
                                                   'notebooks/*',
                                                   'notebooks/images/*']}

install_requires = \
['O365',
 'accelerate==0.17.1',
 'addict',
 'albumentations',
 'arxiv',
 'asyncio',
 'basicsr',
 'beautifulsoup4==4.11.2',
 'bitsandbytes==0.37.2',
 'black==23.1.0',
 'boto3',
 'bs4',
 'celery==5.2.7',
 'controlnet-aux',
 'diffusers==0.14.0',
 'duckduckgo_search',
 'einops',
 'faiss-cpu',
 'fastapi==0.94.1',
 'ggl',
 'google-api-python-client',
 'google-auth-httplib2',
 'google-auth-oauth',
 'google-search-results==2.4.2',
 'gradio',
 'gradio_tools',
 'httpx',
 'imageio',
 'imageio-ffmpeg',
 'jinja2==3.1.2',
 'kornia',
 'langchain',
 'llama-index',
 'nest_asyncio',
 'numpy',
 'omegaconf',
 'open_clip_torch',
 'openai',
 'opencv-python',
 'pillow==9.4.0',
 'playwright',
 'prettytable',
 'psycopg2-binary==2.9.5',
 'pydantic==1.10.6',
 'pydub',
 'python-dotenv==1.0.0',
 'python-multipart==0.0.6',
 'python-ptrace==0.9.8',
 'pytube',
 'redis==4.5.4',
 'safetensors',
 'sentencepiece==0.1.97',
 'streamlit',
 'tenacity==8.2.2',
 'test-tube',
 'timm',
 'torch',
 'torchmetrics',
 'torchvision',
 'transformers',
 'uvicorn==0.21.1',
 'webdataset',
 'wget==3.2',
 'wikipedia==1.4.0',
 'wolframalpha',
 'yapf']

setup_kwargs = {
    'name': 'swarms',
    'version': '0.6.1',
    'description': 'Swarms - Pytorch',
    'long_description': '# Agora\n\n![Agora banner](images/Agora-Banner-blend.png)\n\n[Swarms is brought to you by Agora, the open source AI research organization. Join Agora and Help create swarms and or recieve support to advance Humanity. ](https://discord.gg/qUtxnK2NMf)\n\n# Swarming Language Models (Swarms)\n\n![Swarming banner](images/swarms.png)\n\n[![Share on Twitter](https://img.shields.io/twitter/url/https/twitter.com/cloudposse.svg?style=social&label=Share%20%40kyegomez/swarms)](https://twitter.com/intent/tweet?text=Check%20out%20this%20amazing%20AI%20project:%20&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\n[![Share on Facebook](https://img.shields.io/badge/Share-%20facebook-blue)](https://www.facebook.com/sharer/sharer.php?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\n[![Share on LinkedIn](https://img.shields.io/badge/Share-%20linkedin-blue)](https://www.linkedin.com/shareArticle?mini=true&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&title=&summary=&source=)\n\n\nWelcome to Swarms - the future of AI, where we leverage the power of autonomous agents to create \'swarms\' of Language Models (LLM) that work together, creating a dynamic and interactive AI system.\n\n## Vision\nIn the world of AI and machine learning, individual models have made significant strides in understanding and generating human-like text.\n\nBut imagine the possibilities when these models are no longer solitary units, but part of a cooperative and communicative swarm. This is the future we envision.\n\nJust as a swarm of bees works together, communicating and coordinating their actions for the betterment of the hive, swarming LLM agents can work together to create richer, more nuanced outputs. \n\nBy harnessing the strengths of individual agents and combining them through a swarming architecture, we can unlock a new level of performance and responsiveness in AI systems. We envision swarms of LLM agents revolutionizing fields like customer support, content creation, research, and much more.\n\n\n## Table of Contents\n1. [Installation](#installation)\n2. [Sharing](#sharing)\n\n## Installation\nThere are 2 methods, one is through `git clone` and the other is by `pip install swarms`. Check out the [document](/DOCUMENTATION.md) for more information on the classes.\n\n# Method1\n* Pip install `python3 -m pip install swarms`\n\n* Create new python file and unleash superintelligence\n\n```python\n\nfrom swarms import Swarms\n\n# Retrieve your API key from the environment or replace with your actual key\napi_key = "sksdsds"\n\n# Initialize Swarms with your API key\nswarm = Swarms(openai_api_key=api_key)\n\n# Define an objective\nobjective = """\nPlease develop and serve a simple community web service. \nPeople can signup, login, post, comment. \nPost and comment should be visible at once. \nI want it to have neumorphism-style. \nThe ports you can use are 4500 and 6500.\n"""\n\n# Run Swarms\nswarm.run_swarms(objective)\n```\n\n# Method2\nDownload via Github, and install requirements\n```bash\ngit clone https://github.com/kyegomez/swarms.git\ncd swarms\npip install -r requirements.txt\n```\n\n# Method 3\nSimple example by:\n\n* `git cloning https://github.com/kyegomez/swarms.git`\n\n* `cd swarms`\n\n* `python3 -m pip install -r requirements.txt`\n\n* `python3 example.py`\n\n* or create a new file:\n\n```python\nfrom swarms.swarms import Swarms\n\n# Retrieve your API key from the environment or replace with your actual key\napi_key = "sksdsds"\n\n# Initialize Swarms with your API key\nswarm = Swarms(openai_api_key=api_key)\n\n# Define an objective\nobjective = """\nPlease develop and serve a simple community web service. \nPeople can signup, login, post, comment. \nPost and comment should be visible at once. \nI want it to have neumorphism-style. \nThe ports you can use are 4500 and 6500.\n"""\n\n# Run Swarms\nswarm.run_swarms(objective)\n```\n\nThis will create and execute a task to write a summary about the latest news on quantum computing. The result will be the summary of the news.\n\n\n## Share with your Friends\n\nShare on Twitter: [![Share on Twitter](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)](https://twitter.com/intent/tweet?text=Check%20out%20Swarms%20-%20the%20future%20of%20AI%20%23swarms%20%23AI&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\nShare on Facebook: [![Share on Facebook](https://img.shields.io/badge/-Share%20on%20Facebook-blue)](https://www.facebook.com/sharer/sharer.php?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\nShare on LinkedIn: [![Share on LinkedIn](https://img.shields.io/badge/-Share%20on%20LinkedIn-blue)](https://www.linkedin.com/shareArticle?mini=true&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&title=Swarms%20-%20the%20future%20of%20AI&summary=Check%20out%20Swarms%2C%20the%20future%20of%20AI%20where%20swarms%20of%20Language%20Models%20work%20together%20to%20create%20dynamic%20and%20interactive%20AI%20systems.&source=)\n\nShare on Reddit: [![Share on Reddit](https://img.shields.io/badge/-Share%20on%20Reddit-orange)](https://www.reddit.com/submit?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&title=Swarms%20-%20the%20future%20of%20AI)\n\nShare on Hacker News: [![Share on Hacker News](https://img.shields.io/badge/-Share%20on%20Hacker%20News-orange)](https://news.ycombinator.com/submitlink?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&t=Swarms%20-%20the%20future%20of%20AI)\n\nShare on Pinterest: [![Share on Pinterest](https://img.shields.io/badge/-Share%20on%20Pinterest-red)](https://pinterest.com/pin/create/button/?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms&media=https%3A%2F%2Fexample.com%2Fimage.jpg&description=Swarms%20-%20the%20future%20of%20AI)\n\nShare on WhatsApp: [![Share on WhatsApp](https://img.shields.io/badge/-Share%20on%20WhatsApp-green)](https://api.whatsapp.com/send?text=Check%20out%20Swarms%20-%20the%20future%20of%20AI%20%23swarms%20%23AI%0A%0Ahttps%3A%2F%2Fgithub.com%2Fkyegomez%2Fswarms)\n\n## Contribute\nWe\'re always looking for contributors to help us improve and expand this project. If you\'re interested, please check out our [Contributing Guidelines](./CONTRIBUTING.md).\n\nThank you for being a part of our project!\n\n\n# Open Source Roadmap\n\nHere is the detailed roadmap of our priorities and planned features for the near term:\n\n## TODO\n\n* Fix all errors to working prototype\n\n* Create a tool that creates other tools with access to write code, debug, and an architectural argent that creates the architecture and then another agent that creates the code[Architecter(with code examples), code generator (with access to writing code and terminalrools)] -- The Compiler?\n\n* Create a screenshot tool that takes a screen shot and then passes it to a worker multi-modal agent for visual context.\n\n* API endroute in FASTAPI\n\n* Develop Conversational UI with Gradio\n\n* Integrate omni agent as a worker tool\n\n\n1. **Multi-Agent Debate Integration**: Integrate multi-agent debate frameworks ([Multi Agent debate](https://github.com/Skytliang/Multi-Agents-Debate) and [Multi agent2 debate](https://github.com/composable-models/llm_multiagent_debate)) to improve decision-making.\n\n2. **Meta Prompting Integration**: Include meta prompting across all worker agents to guide their actions.\n\n3. **Swarms Class**: Create a main swarms class `swarms(\'Increase sales by 40$\', workers=4)` for managing and coordinating multiple worker nodes.\n\n4. **Integration of Additional Tools**: Integrate [Jarvis](https://github.com/microsoft/JARVIS) as worker nodes, add text to speech and text to script tools ([whisper x](https://github.com/kyegomez/youtubeURL-to-text)), and integrate Hugging Face agents and other external tools.\n\n5. **Task Completion and Evaluation Logic**: Include task completion logic with meta prompting, and evaluate task completion on a scale from 0.0 to 1.0.\n\n7. **Ocean Integration**: Use the [Ocean](https://github.com/kyegomez/Ocean) vector database as the main embedding database for all the agents, both boss and worker.\n\n8. **Improved Communication**: Develop a universal vector database that is only used when a task is completed in this format `[TASK][COMPLETED]`.\n\n9. **Testing and Evaluation**: Create unit tests, benchmarks, and evaluations for performance monitoring and continuous improvement.\n\n10. **Worker Swarm Class**: Create a class for self-scaling worker swarms. If they need help, they can spawn an entirely new worker and more workers if needed.\n\n## Documentation\n\n1. **Examples**: Create extensive and useful examples for a variety of use cases.\n\n2. **README**: Update the README to include the examples and usage instructions.\n\n\n# Mid-Long term\nHere are some potential middle-to-long-term improvements to consider for this project:\n\n1. **Modular Design**: Aim to design a more modular and scalable framework, making it easy for developers to plug-and-play various components.\n\n2. **Interactive User Interface**: Develop a more interactive, user-friendly GUI that allows users to interact with the system without needing to understand the underlying code.\n\n3. **Advanced Error Handling**: Implement advanced error handling and debugging capabilities to make it easier for developers to diagnose and fix issues.\n\n4. **Optimized Resource Utilization**: Improve the efficiency of resource use, aiming to reduce memory consumption and improve speed without sacrificing accuracy.\n\n5. **Collaborative Learning**: Integrate more sophisticated techniques for collaborative learning among the swarm, allowing them to share knowledge and learn from each other\'s successes and failures.\n\n6. **Autonomous Self-Improvement**: Implement mechanisms that allow the swarm to autonomously learn from its past experiences and improve its performance over time.\n\n7. **Security Enhancements**: Include robust security measures to protect sensitive data and prevent unauthorized access.\n\n8. **Privacy-Preserving Techniques**: Consider incorporating privacy-preserving techniques such as differential privacy to ensure the confidentiality of user data.\n\n9. **Support for More Languages**: Expand language support to allow the system to cater to a more global audience.\n\n10. **Robustness and Resilience**: Improve the system\'s robustness and resilience, ensuring that it can operate effectively even in the face of hardware or software failures.\n\n11. **Continual Learning**: Implement continual learning techniques to allow the system to adapt and evolve as new data comes in.\n\n12. **More Contextual Understanding**: Enhance the system\'s capability to understand context better, making it more effective in handling real-world, complex tasks.\n\n13. **Dynamic Task Prioritization**: Develop advanced algorithms for dynamic task prioritization, ensuring that the most important tasks are addressed first.\n\n14. **Expanding the Swarm\'s Skills**: Train the swarm on a wider range of tasks, gradually expanding their skill set and problem-solving capabilities.\n\n15. **Real-World Deployment**: Test and refine the system in real-world settings, learning from these experiences to further improve and adapt the system. \n\nRemember, these are potential improvements. It\'s important to revisit your priorities regularly and adjust them based on project needs, feedback, and learning from both successes and failures.\n\n## Optimization Priorities\n\n1. **Reliability**: Increase the reliability of the swarm - obtaining the desired output with a basic and un-detailed input.\n\n2. **Speed**: Reduce the time it takes for the swarm to accomplish tasks by improving the communication layer, critiquing, and self-alignment with meta prompting.\n\n3. **Scalability**: Ensure that the system is asynchronous, concurrent, and self-healing to support scalability.\n\nOur goal is to continuously improve Swarms by following this roadmap, while also being adaptable to new needs and opportunities as they arise.\n\n\n# Bounty Program\n\nOur bounty program is an exciting opportunity for contributors to help us build the future of Swarms. By participating, you can earn rewards while contributing to a project that aims to revolutionize digital activity.\n\nHere\'s how it works:\n\n1. **Check out our Roadmap**: We\'ve shared our roadmap detailing our short and long-term goals. These are the areas where we\'re seeking contributions.\n\n2. **Pick a Task**: Choose a task from the roadmap that aligns with your skills and interests. If you\'re unsure, you can reach out to our team for guidance.\n\n3. **Get to Work**: Once you\'ve chosen a task, start working on it. Remember, quality is key. We\'re looking for contributions that truly make a difference.\n\n4. **Submit your Contribution**: Once your work is complete, submit it for review. We\'ll evaluate your contribution based on its quality, relevance, and the value it brings to Swarms.\n\n5. **Earn Rewards**: If your contribution is approved, you\'ll earn a bounty. The amount of the bounty depends on the complexity of the task, the quality of your work, and the value it brings to Swarms.\n\n## The Three Phases of Our Bounty Program\n\n### Phase 1: Building the Foundation\nIn the first phase, our focus is on building the basic infrastructure of Swarms. This includes developing key components like the Swarms class, integrating essential tools, and establishing task completion and evaluation logic. We\'ll also start developing our testing and evaluation framework during this phase. If you\'re interested in foundational work and have a knack for building robust, scalable systems, this phase is for you.\n\n### Phase 2: Optimizing the System\nIn the second phase, we\'ll focus on optimizng Swarms by integrating more advanced features, improving the system\'s efficiency, and refining our testing and evaluation framework. This phase involves more complex tasks, so if you enjoy tackling challenging problems and contributing to the development of innovative features, this is the phase for you.\n\n### Phase 3: Towards Super-Intelligence\nThe third phase of our bounty program is the most exciting - this is where we aim to achieve super-intelligence. In this phase, we\'ll be working on improving the swarm\'s capabilities, expanding its skills, and fine-tuning the system based on real-world testing and feedback. If you\'re excited about the future of AI and want to contribute to a project that could potentially transform the digital world, this is the phase for you.\n\nRemember, our roadmap is a guide, and we encourage you to bring your own ideas and creativity to the table. We believe that every contribution, no matter how small, can make a difference. So join us on this exciting journey and help us create the future of Swarms.\n\n<!-- **To participate in our bounty program, visit the [Swarms Bounty Program Page](https://swarms.ai/bounty).** Let\'s build the future together! -->\n\n\n\n# Inspiration\n\n\n* [🐪CAMEL🐪](https://twitter.com/hwchase17/status/1645834030519296000)\n* [MultiAgent](https://github.com/rumpfmax/Multi-GPT/blob/master/multigpt/multi_agent_manager.py)\n* [AutoGPT](https://github.com/Significant-Gravitas/Auto-GPT)\n\n* [SuperAGI]()\n* [AgentForge](https://github.com/DataBassGit/AgentForge)\n* [Voyager](https://github.com/MineDojo/Voyager)\n\n\n* [Gorilla: Large Language Model Connected with Massive APIs](https://arxiv.org/abs/2305.15334)\n* [LLM powered agents](https://lilianweng.github.io/posts/2023-06-23-agent/)\n\n\n## Agent System Overview\nIn a LLM-powered autonomous agent system, LLM functions as the agent’s brain, complemented by several key components:\n\n* Planning Subgoal and decomposition: The agent breaks down large tasks into smaller, manageable subgoals, enabling efficient handling of complex tasks.\nReflection and refinement: The agent can do self-criticism and self-reflection over past actions, learn from mistakes and refine them for future steps, thereby improving the quality of final results.\n\n* Memory Short-term memory: I would consider all the in-context learning (See Prompt Engineering) as utilizing short-term memory of the model to learn.\nLong-term memory: This provides the agent with the capability to retain and recall (infinite) information over extended periods, often by leveraging an external vector store and fast retrieval.\n\n* Tool use\nThe agent learns to call external APIs for extra information that is missing from the model weights (often hard to change after pre-training), including current information, code execution capability, access to proprietary information sources and more.\n\n* Communication -> How reliable and fast is the communication between each indivual agent.\n\n',
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
